@@ -2,6 +2,10 @@ from hashlib import md5
 from requests import Session
 
 
+class PicnicAuthError(Exception):
+    """Indicates an error when authenticating to the Picnic API."""
+
+
 class PicnicAPISession(Session):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -30,7 +34,10 @@ class PicnicAPISession(Session):
         data = {"key": username, "secret": secret, "client_id": 1}
 
         response = self.post(url, json=data)
+        if "x-picnic-auth" not in response.headers:
+            raise PicnicAuthError("Could not authenticate against Picnic API")
+
         self.headers.update({"x-picnic-auth": response.headers["x-picnic-auth"]})
 
 
-__all__ = ["PicnicAPISession"]
+__all__ = ["PicnicAuthError", "PicnicAPISession"]
